"""Dali Gateway Types"""

from typing import TypedDict


class DeviceProperty:
    dpid: int
    data_type: str


class DeviceType(TypedDict):
    unique_id: str
    id: str
    name: str
    dev_type: str
    channel: int
    address: int
    status: str
    dev_sn: str
    area_name: str
    area_id: str
    prop: list[DeviceProperty]


class GroupType(TypedDict):
    unique_id: str
    id: int
    name: str
    channel: int
    area_id: str


class SceneType(TypedDict):
    unique_id: str
    id: int
    name: str
    channel: int
    area_id: str


class DaliGatewayType(TypedDict):
    gw_sn: str
    gw_ip: str
    port: int
    name: str
    username: str
    passwd: str
    is_tls: bool
    channel_total: list[int]


class VersionType(TypedDict):
    software: str
    firmware: str



"""Constants for the Dali Center."""

from importlib import resources

DOMAIN = "dali_center"

DEVICE_TYPE_MAP = {
    "0101": "Dimmer",
    "0102": "CCT",
    "0103": "RGB",
    "0104": "XY",
    "0105": "RGBW",
    "0106": "RGBWA",
    "0201": "Motion",
    "0202": "Illuminance",
    "0302": "2-Key Panel",
    "0304": "4-Key Panel",
    "0306": "6-Key Panel",
    "0308": "8-Key Panel",
}

COLOR_MODE_MAP = {
    "0102": "color_temp",  # CCT
    "0103": "hs",          # RGB
    "0104": "hs",          # XY
    "0105": "rgbw",        # RGBW
    "0106": "rgbw",        # RGBWA
}

BUTTON_EVENTS = {
    1: "single_click",
    2: "long_press",
    3: "double_click",
    4: "rotate",
    5: "long_press_stop",
}

CA_CERT_PATH = resources.files("PySrDaliGateway") / "certs" / "ca.crt"
